# PsyLab - Psychophysics Lab

## About

Psylab is a loose collection of modules useful for various aspects of running
psychophysical experiments, although several might be more generally useful.

- Current version: 1.0.2
- [License](COPYING)
- [Website](https://github.com/cbrown1/psylab)
- [Version History](NEWS.md)
- [Authors](AUTHORS.md)
- [Installation instructions](INSTALL.md)

## Copyright & License

*Copyright (c) 2010-2020 Christopher A. Brown*

Psylab is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Psylab is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see http://www.gnu.org/licenses/.

